@@ -70,6 +70,16 @@ class Api(snappi.Api):
         self.capture = Capture(self)
         self.protocol_metrics = ProtocolMetrics(self)
         self.resource_group = ResourceGroup(self)
+        self.do_compact = False
+        self._dev_compacted = {}
+        self.compacted_ref = {}
+        self._previous_errors = []
+        self._ixn_obj_info =  namedtuple(
+            "IxNobjInfo", ["xpath", "href", "index", "multiplier", "compacted"]
+        )
+        self._ixn_route_info = namedtuple(
+            "IxnRouteInfo", ["ixn_obj", "index", "multiplier"]
+        )
 
     def _get_addr_port(self, host):
         items = host.split("/")
@@ -84,35 +94,84 @@ class Api(snappi.Api):
             else:
                 return addr, "80"
 
+    def enable_scaling(self, do_compact = False):
+        self.do_compact = do_compact
+    
     @property
     def snappi_config(self):
         return self._config
-
+    
     def get_config_object(self, name):
         try:
             return self._config_objects[name]
         except KeyError:
             raise NameError("snappi object named {0} not found".format(name))
 
+    def get_ixn_href(self, name):
+        """Returns an href given a unique configuration name"""
+        return self._ixn_objects[name].href
+
+    def get_ixn_object(self, name):
+        try:
+            return self._ixn_objects[name]
+        except KeyError:
+            raise NameError("snappi object named {0} not found in get_ixn_object".format(name))
+    
+    def set_ixn_object(self, name, href, xpath=None):
+        self._ixn_objects[name] = self._ixn_obj_info(
+            xpath=xpath,
+            href=href,
+            index=1,
+            multiplier=1,
+            compacted=False
+        )
+        
+    def set_ixn_cmp_object(self, snappi_obj, href, xpath=None, multiplier=1):
+        names = snappi_obj.get("name_list")
+        if names is None:
+            name = snappi_obj.get("name")
+            if name is None:
+                raise Exception(
+                    "Problem at the time of parsing set_ixn_cmp_object"
+                )
+            self._ixn_objects[name] = self._ixn_obj_info(
+                xpath=xpath,
+                href=href,
+                index=1,
+                multiplier=multiplier,
+                compacted=False
+            )
+        else:
+            self.compacted_ref[xpath] = names
+            for index, name in enumerate(names):
+                self._ixn_objects[name] = self._ixn_obj_info(
+                    xpath=xpath,
+                    href=href,
+                    index=multiplier * index + 1,
+                    multiplier=multiplier,
+                    compacted=True
+                )
+    
     def get_device_encap(self, name):
         try:
             return self._device_encap[name]
         except KeyError:
             raise NameError("snappi object named {0} not found".format(name))
 
-    @property
-    def ixn_objects(self):
-        """A dict of all model unique names to ixn hrefs"""
-        return self._ixn_objects
-
-    def get_ixn_object(self, name):
-        """Returns an ixnetwork_restpy object given a unique configuration name"""
-        href = self.get_ixn_href(name)
-        return self._assistant.Session.GetObjectFromHref(href)
-
-    def get_ixn_href(self, name):
-        """Returns an href given a unique configuration name"""
-        return self._ixn_objects[name]
+    def set_device_encap(self, obj, type):
+        if isinstance(obj, str):
+            self._device_encap[obj] = type
+        names = obj.get("name_list")
+        if names is None:
+            name = obj.get("name")
+            if name is None:
+                raise Exception(
+                    "Problem at the time of parsing set_device_encap"
+                )
+            self._device_encap[name] = type
+        else:
+            for name in names:
+                self._device_encap[name] = type
 
     @property
     def ixn_route_objects(self):
@@ -123,10 +182,36 @@ class Api(snappi.Api):
             raise Exception("%s not within configure routes" % name)
         return self._ixn_route_objects[name]
 
+    def set_route_objects(self, ixn_bgp_property, route_obj, multiplier=1):
+        names = route_obj.get("name_list")
+        if names is None:
+            name = route_obj.get("name")
+            if name is None:
+                raise Exception(
+                    "Problem at the time of parsing set_route_objects"
+                )
+            self._ixn_route_objects[name] = self._ixn_route_info(
+                ixn_obj=ixn_bgp_property,
+                index=1,
+                multiplier=multiplier
+            )
+        else:
+            for index, name in enumerate(names):
+                self._ixn_route_objects[name] = self._ixn_route_info(
+                    ixn_obj=ixn_bgp_property,
+                    index=index * multiplier,
+                    multiplier=multiplier
+                )
+
     @property
     def assistant(self):
         return self._assistant
 
+    def set_dev_compacted(self, device):
+        dev_name = device["name"]
+        for index, name in enumerate(device["name_list"]):
+            self._dev_compacted[name] = {"dev_name": dev_name, "index": index}
+
     def _dict_to_obj(self, source):
         """Returns an object given a dict"""
         if isinstance(source, list):
@@ -183,29 +268,39 @@ class Api(snappi.Api):
             self.config_ixnetwork(config)
         except Exception as err:
             raise SnappiIxnException(err)
+
+        bad_requests = self.get_json_import_errors()
+        if bad_requests != []:
+            bad_requests.insert(0, "bad request errors from Ixn:")
+            raise SnappiIxnException(400, bad_requests)
+        return self._request_detail()
+
+    def get_json_import_errors(self):
         app_errors = self._globals.AppErrors.find()
         bad_requests = []
         if len(app_errors) > 0:
             current_errors = app_errors[0].Error.find()
             if len(current_errors) > 0:
                 for error in current_errors:
-                    if error.Name == "JSON Import Issues":
-                        bad_requests = [
-                            instance.SourceValues[0]
-                            for instance in error.Instance.find()
-                        ]
-        if bad_requests:
-            if len(bad_requests) == 1:
-                raise SnappiIxnException(
-                    400, "Bad request error: {}".format(bad_requests[0])
-                )
-            raise SnappiIxnException(400, "Bad request errors:", bad_requests)
-        return self._request_detail()
+                    if error.Name != "JSON Import Issues":
+                        continue
+                    for instance in error.Instance.find():
+                        if instance.SourceValues in self._previous_errors:
+                            continue
+                        bad_requests.append(instance.SourceValues[0])
+                        # this is for linux as it is retaining errors from
+                        # previous run and raising exception in the latest
+                        # script run
+                        self._previous_errors.append(instance.SourceValues)
+        return bad_requests
 
     def config_ixnetwork(self, config):
         self._config_objects = {}
         self._device_encap = {}
         self._ixn_objects = {}
+        self._ixn_route_objects = {}
+        self._dev_compacted = {}
+        self.compacted_ref = {}
         self._connect()
         self.capture.reset_capture_request()
         self._config = self._validate_instance(config)
@@ -219,8 +314,7 @@ class Api(snappi.Api):
             self.lag.config()
             with Timer(self, "Devices configuration"):
                 self.ngpf.config()
-            with Timer(self, "Flows configuration"):
-                self.traffic_item.config()
+            self.traffic_item.config()
         self._running_config = self._config
         self._apply_change()
 
@@ -551,7 +645,7 @@ class Api(snappi.Api):
         if response.status_code == 202:
             content = response.json()
             while content["state"] == "IN_PROGRESS":
-                time.sleep(1)
+                time.sleep(0.2)
                 response = self._request("GET", content["url"])
         if response.headers.get("Content-Type"):
             if response.headers["Content-Type"] == "application/json":
@@ -566,7 +660,14 @@ class Api(snappi.Api):
         """Remove any ixnetwork objects that are not found in the items list.
         If the items list does not exist remove everything.
         """
-        valid_names = [item.name for item in items if item.name is not None]
+        valid_names = []
+        for item in items:
+            if isinstance(item, dict):
+                name = item.get("name")
+            else:
+                name = item.name
+            if name is not None:
+                valid_names.append(name)
         invalid_names = []
         for item in ixn_obj.find():
             if item.Name not in valid_names:
